@@ -837,7 +837,7 @@ void test(const char *vector, unsigned char *digest,
     output[2 * digest_size] = '\0';
 
     for (i = 0; i < (int) digest_size ; i++) {
-       sprintf(output + 2 * i, "%02x", digest[i]);
+       snprintf(output+2*i, (sizeof(output) - strlen(output)), "%02x", digest[i]);
     }
 
     printf("H: %s\n", output);
