@@ -11,7 +11,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: stackio.c 7705M 2019-07-23 14:46:51Z (local) $";
+static char rcsid[] = "$Id: stackio.c 8084 2019-08-30 23:01:18Z jccleaver $";
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -380,10 +380,14 @@ static void addtofnlist(char *dirname, int is_optional, void **v_listhead)
 		if ((fnlen >= 8) && ((strcmp(d->d_name + fnlen - 8, ".rpmsave") == 0) || (strcmp(d->d_name + fnlen - 8, ".rpmorig") == 0) ) ) continue;
 		if ((fnlen >= 7) && (strcmp(d->d_name + fnlen - 7, ".rpmnew") == 0)) continue;
 
+#if __GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6)
 		#pragma GCC diagnostic push
 		#pragma GCC diagnostic ignored "-Wformat-truncation"
+#endif  // __GNUC__
 		snprintf(fn, sizeof(fn), "%s/%s", dirfn, d->d_name);
+#if __GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6)
 		#pragma GCC diagnostic pop
+#endif  // __GNUC__
 		if (stat(fn, &st) == -1) continue;
 
 		if (S_ISDIR(st.st_mode)) {
