@@ -8,7 +8,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char netstat_rcsid[] = "$Id: do_netstat.c 7609 2015-03-22 00:21:16Z jccleaver $";
+static char netstat_rcsid[] = "$Id: do_netstat.c 8036 2019-03-20 23:20:21Z jccleaver $";
 
 static char *netstat_params[] = { "DS:udpInDatagrams:DERIVE:600:0:U", 
 	                          "DS:udpOutDatagrams:DERIVE:600:0:U", 
@@ -265,8 +265,8 @@ static char *netstat_freebsd_markers[] = {
 	NULL
 };
 
-/* This one matches all Linux systems */
-static char *netstat_linux_markers[] = {
+/* This one matches most older Linux systems using traditional netstat */
+static char *netstat_linux_legacy_markers[] = {
 	"packets received",
 	"packets sent",
 	"packet receive errors",
@@ -286,6 +286,27 @@ static char *netstat_linux_markers[] = {
 	NULL
 };
 
+/* This one matches Linux systems using net-tools from approx 2016 onwards */
+static char *netstat_linux_markers[] = {
+	"packets received",
+	"packets sent",
+	"packet receive errors",
+	"active connection openings",
+	"passive connection openings",
+	"failed connection attempts",
+	"connection resets received",
+	"connections established",
+	"",
+	"",
+	"",
+	"",
+	"segments sent out",
+	"segments received",
+	"",
+	"segments retransmitted",
+	NULL
+};
+
 // /* This one matches sco_sv systems -- useless :( */
 // static char *netstat_sco_sv_markers[] = {
 //         "input packets delivered",
@@ -506,7 +527,13 @@ int do_netstat_rrd(char *hostname, char *testname, char *classname, char *pagepa
 	  case OS_ZOS:
 		/* These are of the form "<value> <marker" */
 		datapart = strstr(datapart, "\nTcp:");	/* Skip to the start of "Tcp" (udp comes after) */
-		if (datapart) havedata = do_valbeforemarker(netstat_linux_markers, datapart, outp);
+
+		/* The net-tools project changed formats recently, but not in enough */
+		/* of a way to warrant switching to regex; we can branch on a former typo. */
+		if (datapart) {
+			if (strstr(datapart, "segments sent out")) havedata = do_valbeforemarker(netstat_linux_markers, datapart, outp);
+			else havedata = do_valbeforemarker(netstat_linux_legacy_markers, datapart, outp);
+		}
 		break;
 
 	  case OS_SNMP:
