@@ -11,7 +11,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: xymond_client.c 7886 2016-02-02 20:16:19Z jccleaver $";
+static char rcsid[] = "$Id: xymond_client.c 8066 2019-05-03 22:42:00Z jccleaver $";
 
 #include <stdio.h>
 #include <string.h>
@@ -40,6 +40,7 @@ typedef struct sectlist_t {
 } sectlist_t;
 static sectlist_t *defsecthead = NULL;
 
+int cpulistincpu = 1;
 int pslistinprocs = 1;
 int portlistinports = 1;
 int svclistinsvcs = 1;
@@ -513,7 +514,7 @@ void unix_cpu_report(char *hostname, char *clientclass, enum ostype_t os,
 		addtostrstatus(cpumsg);
 		addtostatus("\n");
 	}
-	if (topstr) {
+	if (topstr && cpulistincpu == 1) {
 		addtostatus("\n");
 		addtostatus(topstr);
 	}
@@ -942,11 +943,9 @@ void unix_memory_report(char *hostname, char *clientclass, enum ostype_t os,
 	else invaliddata = 1;
 
 	if (memactused != -1) memactpct = (memacttotal > 0) ? ((100 * memactused) / memacttotal) : 0;
-	if (memactpct <= 100) {
+	/* Actual percentage can be above 100 */
 		if (memactpct  > actyellow)  actcolor  = COL_YELLOW;
 		if (memactpct  > actred)     actcolor  = COL_RED;
-	}
-	else invaliddata = 1;
 
 	if ((physcolor == COL_RED) || (swapcolor == COL_RED) || (actcolor == COL_RED)) {
 		memorycolor = COL_RED;
@@ -981,12 +980,8 @@ void unix_memory_report(char *hostname, char *clientclass, enum ostype_t os,
 	addtostatus(msgline);
 
 	if (memactused != -1) {
-		if (memactpct <= 100)
-			sprintf(msgline, "&%s %-16s%11ldM%11ldM%11ld%%\n", 
-				colorname(actcolor), "Actual/Virtual", memactused, memacttotal, memactpct);
-		else
-			sprintf(msgline, "&%s %-16s%11ldM%11ldM%11ld%% - invalid data\n", 
-				colorname(COL_YELLOW), "Actual/Virtual", memactused, memacttotal, 0L);
+		sprintf(msgline, "&%s %-16s%11ldM%11ldM%11ld%%\n", 
+			colorname(actcolor), "Actual/Virtual", memactused, memacttotal, memactpct);
 			
 		addtostatus(msgline);
 	}
@@ -2088,6 +2083,9 @@ int main(int argc, char *argv[])
 		else if (strcmp(argv[argi], "--no-port-listing") == 0) {
 			portlistinports = 0;
 		}
+		else if (strcmp(argv[argi], "--no-cpu-listing") == 0) {
+			cpulistincpu = 0;
+		}
 		else if (strcmp(argv[argi], "--no-clear-msgs") == 0) {
 			sendclearmsgs = 0;
 		}
