@@ -13,7 +13,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: xymond_history.c 7678 2015-10-01 14:42:42Z jccleaver $";
+static char rcsid[] = "$Id: xymond_history.c 8080 2019-08-21 15:38:53Z jccleaver $";
 
 #include <sys/types.h>
 #include <stdio.h>
@@ -170,8 +170,11 @@ int main(int argc, char *argv[])
 		alleventsfd = fopen(alleventsfn, "a");
 		if (alleventsfd == NULL) {
 			errprintf("Cannot open the all-events file '%s'\n", alleventsfn);
+			return 1;
+		}
+		else {
+			setvbuf(alleventsfd, (char *)NULL, _IOLBF, 0);
 		}
-		setvbuf(alleventsfd, (char *)NULL, _IOLBF, 0);
 	}
 
 	/* For picking up lost children */
